import androidx.compose.desktop.ui.tooling.preview.Preview
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.window.Window
import androidx.compose.ui.window.application
import androidx.compose.foundation.layout.*
import androidx.compose.material.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Close
import javax.swing.JFileChooser
import javax.swing.filechooser.FileNameExtensionFilter
import java.io.File




@Composable
fun HomePage(
    onGlossaireClick: () -> Unit,
    onCodeAVerifierClick: () -> Unit
) {
    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally

    ) {
        Text("Quali'Nomme", style = MaterialTheme.typography.h3)

        Spacer(modifier = Modifier.height(16.dp))

        Row(
            horizontalArrangement = Arrangement.spacedBy(16.dp)
        ) {
            Button(onClick = onGlossaireClick) {
                Text("Glossaire")
            }

            Button(onClick = onCodeAVerifierClick ) {
                Text("Code à Vérifier")
            }

            Button(onClick = { /* Action de Comparer */ }) {
                Text("Comparer")
            }
        }
    }
}

@Composable
@Preview
fun App() {
    MaterialTheme {
        val currentPage = remember { mutableStateOf("accueil") }

        when (currentPage.value) {
            "accueil" -> {
                HomePage(
                    onGlossaireClick = { currentPage.value = "glossaire" },
                    onCodeAVerifierClick = { currentPage.value = "choixLangage" }
                )
            }
            "glossaire" -> {
                glossairePage(
                    onAjouterMotClick = { currentPage.value = "formulaire" },
                    onImporterClick = {
                                    val fileChooser = JFileChooser()
                                    fileChooser.fileFilter = FileNameExtensionFilter("CSV Files", "csv")
                                    val returnVal = fileChooser.showOpenDialog(null)
                                    if (returnVal == JFileChooser.APPROVE_OPTION) {
                                        val file = fileChooser.selectedFile
                                        println("Opening: " + file.name + ".")
                                    } else {
                                        println("Open command cancelled by user.")
                                    }
                    },
                    onExporterClick = { /* Action d'export */ },
                    onRetourClick = { currentPage.value = "accueil" }
                )
            }
            "formulaire" -> {
                FormulairePage(onAnnulerClick = { currentPage.value = "glossaire" })
            }
            "choixLangage" -> {
                ChoixLangagePage(
                    onRetourClick = { currentPage.value = "accueil" },
                    onPythonClick = {
                                    val fileChooser = JFileChooser()
                                    fileChooser.fileFilter = FileNameExtensionFilter("Python Files", "py")
                                    val returnVal = fileChooser.showOpenDialog(null)
                                    if (returnVal == JFileChooser.APPROVE_OPTION) {
                                        val file = fileChooser.selectedFile
                                        println("Opening: " + file.name + ".")
                                    } else {
                                        println("Open command cancelled by user.")
                                    }
                    },
                    onJavaClick = {
                                    val fileChooser = JFileChooser()
                                    fileChooser.fileFilter = FileNameExtensionFilter("Java Files", "java")
                                    val returnVal = fileChooser.showOpenDialog(null)
                                    if (returnVal == JFileChooser.APPROVE_OPTION) {
                                        val file = fileChooser.selectedFile
                                        println("Opening: " + file.name + ".")
                                    } else {
                                        println("Open command cancelled by user.")
                                    }
                    },
                    onJavaScriptClick = {
                                    val fileChooser = JFileChooser()
                                    fileChooser.fileFilter = FileNameExtensionFilter("JavaScript Files", "js")
                                    val returnVal = fileChooser.showOpenDialog(null)
                                    if (returnVal == JFileChooser.APPROVE_OPTION) {
                                        val file = fileChooser.selectedFile
                                        println("Opening: " + file.name + ".")
                                    } else {
                                        println("Open command cancelled by user.")
                                    }
                    }
                )
            }
            // ... Ajoutez d'autres cas pour les pages "glossaire," "code a verifier," et "comparer"
        }
    }
}


@Composable
fun ChoixLangagePage(
    onRetourClick: () -> Unit,
    onPythonClick: () -> Unit,
    onJavaClick: () -> Unit,
    onJavaScriptClick: () -> Unit
) {

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Top, // Align content at the top
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text(text = "Choix du langage", style = MaterialTheme.typography.h3)
    }

    Column(
        modifier = Modifier
            .fillMaxSize()  // Fills the maximum available width
            .padding(50.dp),
        // allign the content in the center vertically and horizontally
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally

    ) {
        Button(onClick = onPythonClick) {
            Text("Python")
        }

        Button(onClick = onJavaClick) {
            Text("Java")
        }

        Button(onClick = onJavaScriptClick) {
            Text("JavaScript")
        }
    }

    // Bouton retour positionné tout en bas et centré horizontalement
    Column(
        modifier = Modifier.fillMaxSize().padding(20.dp),
        verticalArrangement = Arrangement.Bottom,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Button(onClick = onRetourClick) {
            Text("Retour")
        }
    }

}

@Composable
fun glossairePage(
    onAjouterMotClick: () -> Unit,
    onImporterClick: () -> Unit,
    onExporterClick: () -> Unit,
    onRetourClick: () -> Unit
) {

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Top, // Align content at the top
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text(text = "Glossaire", style = MaterialTheme.typography.h3)
    }

    Column(
        modifier = Modifier
            .fillMaxSize()  // Fills the maximum available width
            .padding(16.dp),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally

    ) {

        Button(onClick = onAjouterMotClick) {
            Text("Ajouter un mot")
        }

        Button(onClick = onImporterClick) {
            Text("Importer un fichier CSV")
        }

        Button(onClick = onExporterClick) {
            Text("Exporter un fichier CSV")
        }

    }

    // Bouton retour positionné tout en bas et centré horizontalement
    Column(
        modifier = Modifier.fillMaxSize().padding(20.dp),
        verticalArrangement = Arrangement.Bottom,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Button(onClick = onRetourClick) {
            Text("Retour")
        }
    }

}



@Composable
fun FormulairePage(onAnnulerClick: () -> Unit) {
    MaterialTheme {
        Column(
            modifier = Modifier.padding(16.dp),
            verticalArrangement = Arrangement.spacedBy(8.dp),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text(text = "Nouveau contexte métier", style = MaterialTheme.typography.h5)

            val mot = remember { mutableStateOf("") }
            TextField(
                value = mot.value,
                onValueChange = { mot.value = it },
                label = { Text("Mot") }
            )

            val description = remember { mutableStateOf("") }
            TextField(
                value = description.value,
                onValueChange = { description.value = it },
                label = { Text("Description") }
            )

            val contextePrincipal = remember { mutableStateOf("") }
            TextField(
                value = contextePrincipal.value,
                onValueChange = { contextePrincipal.value = it },
                label = { Text("Contexte principal") }
            )

            val contexte2 = remember { mutableStateOf("") }
            TextField(
                value = contexte2.value,
                onValueChange = { contexte2.value = it },
                label = { Text("Contexte 2") }
            )

            val lieA = remember { mutableStateOf("") }
            TextField(
                value = lieA.value,
                onValueChange = { lieA.value = it },
                label = { Text("Lié à") }
            )

            val synonyme = remember { mutableStateOf("") }
            TextField(
                value = synonyme.value,
                onValueChange = { synonyme.value = it },
                label = { Text("Synonyme") }
            )

            val antonyme = remember { mutableStateOf("") }
            TextField(
                value = antonyme.value,
                onValueChange = { antonyme.value = it },
                label = { Text("Antonyme") }
            )

            Row(
                modifier = Modifier.fillMaxWidth(),
                horizontalArrangement = Arrangement.SpaceEvenly
            ) {
                Button(onClick = onAnnulerClick) {
                    Icon(imageVector = Icons.Default.Close, contentDescription = null)
                    Text("Annuler")
                }
                Button(onClick = { /* Action de validation */ }) {
                    Icon(imageVector = Icons.Default.Check, contentDescription = null)
                    Text("Valider")
                }
            }
        }
    }
}

fun main() = application {
    Window(onCloseRequest = ::exitApplication) {
        App()
    }
}
